==> eui-76.1.0.tgz: package/optimize/es/services/index.js <==
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0 and the Server Side Public License, v 1; you may not use this file except
 * in compliance with, at your election, the Elastic License 2.0 or the Server
 * Side Public License, v 1.
 */
// Export all keys under a `keys` named variable
import * as keys from './keys';
export { accessibleClickKeys, cascadingMenuKeys, comboBoxKeys, htmlIdGenerator, useGeneratedHtmlId } from './accessibility';
export { CENTER_ALIGNMENT, LEFT_ALIGNMENT, RIGHT_ALIGNMENT } from './alignment';
export { CurrentEuiBreakpointContext, CurrentEuiBreakpointProvider, useCurrentEuiBreakpoint, useIsWithinBreakpoints, useIsWithinMaxBreakpoint, useIsWithinMinBreakpoint } from './breakpoint';
export { brighten, calculateContrast, calculateLuminance, colorPalette, darken, DEFAULT_VISUALIZATION_COLOR, desaturate, euiPaletteColorBlind, euiPaletteColorBlindBehindText, euiPaletteComplimentary, euiPaletteCool, euiPaletteForDarkBackground, euiPaletteForLightBackground, euiPaletteForStatus, euiPaletteForTemperature, euiPaletteGray, euiPaletteNegative, euiPalettePositive, euiPaletteWarm, getSteppedGradient, hexToHsv, hexToRgb, hsvToHex, hsvToRgb, isColorDark, isValidHex, lightness, makeDisabledContrastColor, makeHighContrastColor, rgbToHex, rgbToHsv, saturate, shade, shadeOrTint, tint, tintOrShade, transparentize, VISUALIZATION_COLORS, wcagContrastMin } from './color';
export { useColorPickerState, useColorStopsState } from './color_picker';
export * from './console';
export { copyToClipboard } from './copy_to_clipboard';
export * from './findElement';
export { dateFormatAliases, formatAuto, formatBoolean, formatDate, formatNumber, formatText } from './format';
export * from './hooks';
export { isEvenlyDivisibleBy, isWithinRange } from './number';
export { Pager } from './paging';
export { calculatePopoverPosition, findPopoverPosition } from './popover';
export { Random } from './random';
export { getSecureRelForTarget } from './security';
export { Comparators, PropertySortType, SortableProperties, SortDirection, SortDirectionType } from './sort';
export { slugify, toInitials, toSentenceCase } from './string';
export * from './theme';
export { throttle } from './throttle';
export { getDurationAndPerformOnFrame, getTransitionTimings, getWaitDuration, performOnFrame } from './transition';
export { EuiWindowEvent } from './window_event';
export { keys };

==> eui-102.3.0.tgz: package/optimize/es/services/index.js <==
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0 and the Server Side Public License, v 1; you may not use this file except
 * in compliance with, at your election, the Elastic License 2.0 or the Server
 * Side Public License, v 1.
 */

// Export all keys under a `keys` named variable
import * as keys from './keys';
export { htmlIdGenerator, useGeneratedHtmlId } from './accessibility';
export { CENTER_ALIGNMENT, LEFT_ALIGNMENT, RIGHT_ALIGNMENT } from './alignment';
export { CurrentEuiBreakpointContext, CurrentEuiBreakpointProvider, useCurrentEuiBreakpoint, useIsWithinBreakpoints, useIsWithinMaxBreakpoint, useIsWithinMinBreakpoint } from './breakpoint';
export { CanvasTextUtils } from './canvas';
export { brighten, calculateContrast, calculateLuminance, colorPalette, darken, DEFAULT_VISUALIZATION_COLOR, desaturate, euiPaletteColorBlind, euiPaletteColorBlindBehindText, euiPaletteComplementary, euiPaletteCool, euiPaletteForDarkBackground, euiPaletteForLightBackground, euiPaletteForStatus, euiPaletteForTemperature, euiPaletteGray, euiPaletteRed, euiPaletteGreen, euiPaletteWarm, getSteppedGradient, hexToHsv, hexToRgb, hsvToHex, hsvToRgb, isColorDark, isValidHex, lightness, makeDisabledContrastColor, makeHighContrastColor, rgbToHex, rgbToHsv, saturate, shade, shadeOrTint, tint, tintOrShade, transparentize, VISUALIZATION_COLORS, EUI_VIS_COLOR_STORE, wcagContrastMin } from './color';
export * from './color/eui_palettes_hooks';
export { useColorPickerState, useColorStopsState } from './color_picker';
export * from './console';
export * from './copy';
export * from './emotion';
export * from './findElement';
export { dateFormatAliases, formatAuto, formatBoolean, formatDate, formatNumber, formatText } from './format';
export * from './hooks';
export { isEvenlyDivisibleBy, isWithinRange } from './number';
export { Pager } from './paging';
export { calculatePopoverPosition, findPopoverPosition } from './popover';
export { getSecureRelForTarget } from './security';
export { Comparators, PropertySortType, SortableProperties, SortDirection, SortDirectionType } from './sort';
export { slugify, toInitials, toSentenceCase } from './string';
export * from './theme';
export { throttle } from './throttle';
export { getDurationAndPerformOnFrame, getTransitionTimings, getWaitDuration, performOnFrame } from './transition';
export { EuiWindowEvent } from './window_event';
export { keys };
